BuildCommand constructor

BuildCommand()

Constructor for build command Adds arguments for the command

Implementation

BuildCommand() {
  // Add the optional flag for overwriting the Dockerfile
  argParser.addFlag(
    'overwrite-dockerfile',
    abbr: 'o',
    help:
        'If provided, overwrites the existing Dockerfile. Otherwise, it only generates the Dockerfile if it does not exist.',
  );
}